14.127. cdist-type__start_on_boot(7) — cdist 4.8.1 documentation

# 14.127. cdist-type__start_on_boot(7)

## 14.127.1. NAME

cdist-type__start_on_boot - Manage stuff to be started at boot

## 14.127.2. DESCRIPTION

This cdist type allows you to enable or disable stuff to be started at boot of your operating system.

Warning: This type has not been tested intensively and is not fully supported (i.e. *BSD are not implemented).

## 14.127.3. REQUIRED PARAMETERS

None.

## 14.127.4. OPTIONAL PARAMETERS

state
  Either "present" or "absent", defaults to "present"
target_runlevel
  Runlevel which should be modified, defaults to "default" (only used on gentoo systems).

## 14.127.5. EXAMPLES

    # Ensure snmpd is started at boot
    __start_on_boot snmpd

    # Same, but more explicit
    __start_on_boot snmpd --state present

    # Ensure legacy configuration management will not be started
    __start_on_boot puppet --state absent

## 14.127.6. SEE ALSO

cdist-type__process(7)

## 14.127.7. AUTHORS

Nico Schottelius <nico-cdist--@--schottelius.org>

## 14.127.8. COPYING

Copyright (C) 2012 Nico Schottelius. You can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.